mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
* [PATCH] nicstar: Fix a bogus casting warning
@ 2006-10-16 15:27 Alan Cox
  0 siblings, 0 replies; only message in thread
From: Alan Cox @ 2006-10-16 15:27 UTC (permalink / raw)
  To: akpm, linux-kernel, chas

Not enough to make Nicstar 64bit friendly but got squashed in passing so
might as well be applied

Signed-off-by: Alan Cox <alan@redhat.com>

diff -u --new-file --recursive --exclude-from /usr/src/exclude linux.vanilla-2.6.19-rc1-mm1/drivers/atm/nicstar.c linux-2.6.19-rc1-mm1/drivers/atm/nicstar.c
--- linux.vanilla-2.6.19-rc1-mm1/drivers/atm/nicstar.c	2006-10-13 15:10:06.000000000 +0100
+++ linux-2.6.19-rc1-mm1/drivers/atm/nicstar.c	2006-10-13 17:17:57.000000000 +0100
@@ -2759,7 +2759,7 @@
 {
    ns_dev *card;
    pool_levels pl;
-   int btype;
+   long btype;
    unsigned long flags;
 
    card = dev->dev_data;
@@ -2859,7 +2859,7 @@
       case NS_ADJBUFLEV:
          if (!capable(CAP_NET_ADMIN))
 	    return -EPERM;
-         btype = (int) arg;	/* an int is the same size as a pointer */
+         btype = (long) arg;	/* a long is the same size as a pointer or bigger */
          switch (btype)
 	 {
 	    case NS_BUFTYPE_SMALL:


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2006-10-16 15:01 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2006-10-16 15:27 [PATCH] nicstar: Fix a bogus casting warning Alan Cox

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®